Package 'xegaBNF'
| Title: |
Compile a Backus-Naur Form Specification into an R Grammar
Object |
| Description: |
Translates a BNF (Backus-Naur Form) specification of a
context-free language into an R grammar object which consists
of the start symbol, the symbol table, the production table,
and a short production table. The short production table is
non-recursive. The grammar object contains the file name from
which it was generated (without a path). In addition, it
provides functions to determine the type of a symbol
(isTerminal() and isNonterminal()) and functions to access the
production table (rules() and derives()). For the BNF
specification, see Backus, John et al. (1962) "Revised Report
on the Algorithmic Language ALGOL 60". (ALGOL60 standards page
<http://www.algol60.org/2standards.htm>, html-edition
<https://www.masswerk.at/algol60/report.htm>) A preprocessor
for macros which expand to standard BNF is included. The
grammar compiler is an extension of the APL2 implementation in
Geyer-Schulz, Andreas (1997, ISBN:978-3-7908-0830-X). |
| Authors: |
Andreas Geyer-Schulz [aut, cre] (ORCID:
<https://orcid.org/0009-0000-5237-3579>) |
| Maintainer: |
Andreas Geyer-Schulz <[email protected]> |
| License: |
MIT + file LICENSE |
| Version: |
1.0.0.5 |
| Built: |
2026-05-14 05:12:50 UTC |
| Source: |
https://github.com/ageyerschulz/xegabnf |
Help Index